==> component-base-localnews-1.2.2-sources.jar: com/bxm/localnews/common/vo/BasicParam.java <==
package com.bxm.localnews.common.vo;

import com.bxm.newidea.component.vo.BaseBean;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel(description = "api传递的通用基础参数")
public class BasicParam extends BaseBean {

    @ApiModelProperty(value = "通用参数：平台类型,1:ANDROID,2:IOS,3:WEB")
    private int platform;

    @ApiModelProperty(value = "通用参数：当前APP的上线版本")
    private String curVer;

    @ApiModelProperty(value = "通用参数：请求渠道来源")
    private String chnl;

    @ApiModelProperty(value = "通用参数：设备编号")
    private String devcId;

    @ApiModelProperty(value = "通用参数：客户端时间")
    private Long cliTime;

    @ApiModelProperty("通用参数：当前服务端API的版本")
    private String version;

    public int getPlatform() {
        return this.platform;
    }

    public void setPlatform(int platform) {
        this.platform = platform;
    }

    public String getCurVer() {
        return curVer;
    }

    public void setCurVer(String curVer) {
        this.curVer = curVer;
    }

    public String getChnl() {
        return this.chnl;
    }

    public void setChnl(String chnl) {
        this.chnl = chnl;
    }

    public String getDevcId() {
        return devcId;
    }

    public void setDevcId(String devcId) {
        this.devcId = devcId;
    }

    public Long getCliTime() {
        return cliTime;
    }

    public void setCliTime(Long cliTime) {
        this.cliTime = cliTime;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

}

==> component-base-localnews-1.2.4-20190121.050455-1-sources.jar: com/bxm/localnews/common/vo/BasicParam.java <==
package com.bxm.localnews.common.vo;

import com.bxm.newidea.component.vo.BaseBean;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel(description = "api传递的通用基础参数")
public class BasicParam extends BaseBean {

    @ApiModelProperty(value = "通用参数：平台类型,1:ANDROID,2:IOS,3:WEB", required = true)
    private int platform;

    @ApiModelProperty(value = "通用参数：当前APP的上线版本", required = true)
    private String curVer;

    @ApiModelProperty(value = "通用参数：请求渠道来源", required = true)
    private String chnl;

    @ApiModelProperty(value = "通用参数：设备编号", required = true)
    private String devcId;

    @ApiModelProperty(value = "通用参数：客户端时间", required = true)
    private Long cliTime;

    @ApiModelProperty(value = "通用参数：当前服务端API的版本", required = true)
    private String version;

    @ApiModelProperty(value = "操作系统版本", required = true)
    private String operatingSystem;

    public int getPlatform() {
        return this.platform;
    }

    public void setPlatform(int platform) {
        this.platform = platform;
    }

    public String getCurVer() {
        return curVer;
    }

    public void setCurVer(String curVer) {
        this.curVer = curVer;
    }

    public String getChnl() {
        return this.chnl;
    }

    public void setChnl(String chnl) {
        this.chnl = chnl;
    }

    public String getDevcId() {
        return devcId;
    }

    public void setDevcId(String devcId) {
        this.devcId = devcId;
    }

    public Long getCliTime() {
        return cliTime;
    }

    public void setCliTime(Long cliTime) {
        this.cliTime = cliTime;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getOperatingSystem() {
        return operatingSystem;
    }

    public void setOperatingSystem(String operatingSystem) {
        this.operatingSystem = operatingSystem;
    }
}
